.. _support:

Getting Help
============

There are multiple ways of getting help.

Mailing List
------------

A public mailing list for the `zugbruecke project`_ and closely related projects - including *wenv* and `wenv-kernel`_ - for both users and developers is available at `groups.io`_.

.. _groups.io: https://groups.io/g/zugbruecke-dev
.. _zugbruecke project: https://github.com/pleiszenburg/zugbruecke
.. _wenv-kernel: https://github.com/pleiszenburg/wenv-kernel

Chat
----

There is a `dedicated public Matrix chat`_.

.. _dedicated public Matrix chat: https://matrix.to/#/#zugbruecke:matrix.org

Reporting Bugs / Issues
-----------------------

Bugs and any kind of issues should be reported in the project's `Github issue tracker`_, also see :ref:`chapter on bugs <bugs>`.

.. _Github issue tracker: https://github.com/pleiszenburg/wenv/issues

Paid Support
------------

In addition to the previous options, paid support is available from `pleiszenburg.de - Independent Scientific Services`_.

.. _pleiszenburg.de - Independent Scientific Services: https://www.pleiszenburg.de
